@@ -1,9 +1,9 @@
 #' Function to make enrichment results conciser by removing redundant terms
 #'
-#' \code{xEnrichConciser} is supposed to make enrichment results conciser by removing redundant terms. A redundant term (called 'B') is claimed if its overlapped part (A&B) with a more significant term (called 'A') meets both criteria: 1) |A&B| > 0.9*|B|; and 2) |A&B| < 0.5*|A|.
+#' \code{xEnrichConciser} is supposed to make enrichment results conciser by removing redundant terms. A redundant term (called 'B') is claimed if its overlapped part (A&B) with a more significant term (called 'A') meets both criteria: 1) |A&B| > 0.9*|B|; and 2) |A&B| > 0.5*|A|.
 #'
 #' @param eTerm an object of class "eTerm"
-#' @param cutoff a cutoff vector used to remove redundant terms. By default, it has the first element 0.9 and the second element 0.5. It means, for a term (less significant; called 'B'), if there is a more significant term (called 'A'), their overlapped members cover at least 90% of the B's members but less than 50% of the A's members, then this term B will be defined as redundant and thus being removed
+#' @param cutoff a cutoff vector used to remove redundant terms. By default, it has the first element 0.9 and the second element 0.5. It means, for a term (less significant; called 'B'), if there is a more significant term (called 'A'), their overlapped members cover at least 90% of the B's members, and also at less 50% of the A's members, then this term B will be defined as redundant and thus being removed
 #' @param verbose logical to indicate whether the messages will be displayed in the screen. By default, it sets to false for no display
 #' @return
 #' an object of class "eTerm", after redundant terms being removed.
@@ -66,6 +66,7 @@ xEnrichConciser <- function(eTerm, cutoff=c(0.9,0.5), verbose=T)
 		
 	}else{
 		res <- NULL
+		message("The provided object can be used for removing redundant terms.\n")
 	}
     
     res
